@@ -65,9 +65,10 @@ mt_main_current_screen (MTClosure *mt)
 static void
 mt_main_generate_motion_event (GdkScreen *screen, gint x, gint y)
 {
-    gdk_display_warp_pointer (gdk_display_get_default (),
-			      screen, x, y);
+    gdk_error_trap_push ();
+    gdk_display_warp_pointer (gdk_display_get_default (), screen, x, y);
     gdk_flush ();
+    gdk_error_trap_pop ();
 }
 
 static void
@@ -76,6 +77,7 @@ mt_main_generate_button_event (MTClosure *mt,
 			       gboolean   type,
 			       gulong     delay)
 {
+    gdk_error_trap_push ();
     switch (type) {
 	case PRESS:
 	    XTestFakeButtonEvent (mt->xtst_display,
@@ -95,17 +97,18 @@ mt_main_generate_button_event (MTClosure *mt,
 	    XTestFakeButtonEvent (mt->xtst_display,
 				  button, True, CurrentTime);
 	    XTestFakeButtonEvent (mt->xtst_display,
-				  button, True, delay);
+				  button, False, delay);
 	    XTestFakeButtonEvent (mt->xtst_display,
 				  button, True, CurrentTime);
 	    XTestFakeButtonEvent (mt->xtst_display,
-				  button, True, delay);
+				  button, False, delay);
 	    break;
 	default:
 	    g_warning ("Unknown sequence.");
 	    break;
     }
     XFlush (mt->xtst_display);
+    gdk_error_trap_pop ();
 }
 
 static void
@@ -139,7 +142,7 @@ mt_main_do_dwell_click (MTClosure *mt)
 
     clicktype = mt_service_get_clicktype (mt->service);
 
-    if (mt->dwell_mode == DWELL_MODE_GESTURE)
+    if (mt->dwell_mode == DWELL_MODE_GESTURE && !mt->dwell_drag_started)
 	mt_main_generate_motion_event (mt_main_current_screen (mt),
 				       mt->pointer_x, mt->pointer_y);
 
@@ -313,6 +316,10 @@ dwell_timer_finished (MtTimer *timer, gpointer data)
 	    if (mt_main_analyze_gesture (mt))
 		mt_main_do_dwell_click (mt);
 	}
+	/* if a drag action is in progress stop it */
+	else if (mt->dwell_drag_started) {
+	    mt_main_do_dwell_click (mt);
+	}
 	else
 	    dwell_start_gesture (mt);
     }
@@ -518,7 +525,7 @@ cursor_overlay_time (guchar  *image,
 			   c.red   / 65535.,
 			   c.green / 65535.,
 			   c.blue  / 65535.,
-			   0.75);
+			   0.60);
     cairo_fill (cr);
     cairo_destroy (cr);
     cairo_surface_destroy (surface);
@@ -527,7 +534,9 @@ cursor_overlay_time (guchar  *image,
 }
 
 static void
-mt_update_cursor (MtCursor *cursor, MtTimer *timer, gdouble time)
+mt_main_update_cursor (MtCursor *cursor,
+		       MtTimer  *timer,
+		       gdouble   time)
 {
     guchar *image;
     gushort width, height;
@@ -556,21 +565,14 @@ mt_update_cursor (MtCursor *cursor, MtTimer *timer, gdouble time)
 }
 
 static void
-delay_timer_tick (MtTimer *timer, gdouble time, gpointer data)
+mt_main_timer_tick (MtTimer *timer,
+		    gdouble  time,
+		    gpointer data)
 {
     MTClosure *mt = data;
 
     if (mt->animate_cursor && mt->cursor != NULL)
-	mt_update_cursor (mt->cursor, timer, time);
-}
-
-static void
-dwell_timer_tick (MtTimer *timer, gdouble time, gpointer data)
-{
-    MTClosure *mt = data;
-
-    if (mt->animate_cursor && mt->cursor != NULL)
-	mt_update_cursor (mt->cursor, timer, time);
+	mt_main_update_cursor (mt->cursor, timer, time);
 }
 
 static void
@@ -710,12 +712,9 @@ static gboolean
 accessibility_enabled (MTClosure *mt,
 		       gint       spi_status)
 {
-    gboolean a11y;
-
-    a11y = gconf_client_get_bool (mt->client, GNOME_A11Y_KEY, NULL);
-    if (!a11y || spi_status != 0) {
-	gint ret;
+    gint ret;
 
+    if (spi_status != 0) {
 	ret = mt_common_show_dialog
 	    (_("Assistive Technology Support Is Not Enabled"),
 	     _("Mousetweaks requires assistive technologies to be enabled "
@@ -768,13 +767,13 @@ mt_closure_init (void)
     g_signal_connect (mt->delay_timer, "finished",
 		      G_CALLBACK (delay_timer_finished), mt);
     g_signal_connect (mt->delay_timer, "tick",
-		      G_CALLBACK (delay_timer_tick), mt);
+		      G_CALLBACK (mt_main_timer_tick), mt);
 
     mt->dwell_timer = mt_timer_new ();
     g_signal_connect (mt->dwell_timer, "finished",
 		      G_CALLBACK (dwell_timer_finished), mt);
     g_signal_connect (mt->dwell_timer, "tick",
-		      G_CALLBACK (dwell_timer_tick), mt);
+		      G_CALLBACK (mt_main_timer_tick), mt);
 
     mt->service = mt_service_get_default ();
     mt_service_set_clicktype (mt->service, DWELL_CLICK_TYPE_SINGLE, NULL);
